@@ -28,7 +28,7 @@ email                : chubinger@irrsinnig.org
 
 // kde includes
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 namespace KMF {
 
